@@ -8,6 +8,12 @@
 #		Removed the dbadmpass check part.
 #	20031219 Thomas Viehmann <tv@beamnet.de>
 #		Patch to use eval in order to not break.
+#       20040205 Jeroen van Wolffelaar <jeroen@wolffelaar.nl>
+#		 Jeremy <jeremy.laine@polytechnique.org>
+#		Check merely for valid account, rather than for access to the
+#		mysql-database, so also regular mysqlusers can be used
+#	20040705 Jeremy Laine <jeremy.laine@m4x.org>
+#		Better check for mysql client command.
 # Needs:	$dbname    - the database that user should have access to.
 #		$dbserver  - the server to connect to.
 #		$dbadmin   - the administrator name.
@@ -30,10 +36,10 @@ elif [ -z "$dbserver" ] ; then
     error="No database server specified."
 elif [ -z "$dbadmin" ] ; then
     error="No database administrator specified."
-elif [ ! -x $(which mysql) ] ; then
+elif [ -z $(which mysql) ] ; then
     error="No mysql client to execute, install the mysql client package and
     run 'dpkg-reconfigure -plow packagename'."
-elif ! eval $mysqlcmd -f mysql -e "\"show tables;\"" >/dev/null 2>&1 ; then
+elif ! eval $mysqlcmd </dev/null >/dev/null 2>&1 ; then
     error="Error when trying to connect to the mysql database.
     This error can occur if you have no database to connect to, or
     if the password was incorrect.
