@@ -8,6 +8,8 @@
 #		Removed the dbadmpass check part.
 #	20031219 Thomas Viehmann <tv@beamnet.de>
 #		Patch to use eval in order to not break.
+#	20040705 Jeremy Laine <jeremy.laine@m4x.org>
+#		Better check for mysql client command.
 # Needs:	$dbuser    - the user name to create (or replace).
 #		$dballow   - what hosts to allow (defaults to %).
 #		$dbname    - the database that user should have access to.
@@ -34,7 +36,7 @@ elif [ -z "$dbserver" ] ; then
     error="No database server specified."
 elif [ -z "$dbadmin" ] ; then
     error="No database administrator specified."
-elif [ ! -x $(which mysql) ] ; then
+elif [ -z $(which mysql) ] ; then
     echo "No mysql client to execute, install the mysql client package and
     run 'dpkg-reconfigure -plow packagename'."
 elif ! eval $mysqlcmd -f mysql -e "\"show tables;\"" >/dev/null 2>&1 ; then
