@@ -12,9 +12,11 @@
 #		Added new status code.
 #	20031219 Thomas Viehmann <tv@beamnet.de>
 #		Patch to use eval in order to not break.
-#   20040205 Jeroen van Wolffelaar <jeroen@wolffelaar.nl>
+#	20040205 Jeroen van Wolffelaar <jeroen@wolffelaar.nl>
 #		Check merely for valid account, rather than for access to the
 #		mysql-database, so also regular mysqlusers can be used
+#	20040705 Jeremy Laine <jeremy.laine@m4x.org>
+#		Better check for mysql client command.
 # Needs:	$dbname    - the database that user should have access to (optional)
 #		$dbserver  - the server to connect to.
 #		$dbadmin   - the databaseuser name.
@@ -43,7 +45,7 @@ elif [ -z "$sqlfile" ] ; then
     error="No sqlfile to execute."
 elif [ ! -e "$sqlfile" ] ; then
     error="Sqlfile $sqlfile not found."
-elif [ ! -x $(which mysql) ] ; then
+elif [ -z $(which mysql) ] ; then
     error="No mysql client to execute, install the mysql client package and
     run 'dpkg-reconfigure -plow packagename'."
 elif ! eval $mysqlcmd </dev/null >/dev/null 2>&1 ; then
